@@ -1,5 +1,7 @@
 package Email::MIME::RFC2047::AddressList;
-our $VERSION = '0.90';
+BEGIN {
+  $Email::MIME::RFC2047::AddressList::VERSION = '0.91';
+}
 
 use strict;
 use base qw(Email::MIME::RFC2047::Parser);
@@ -52,6 +54,8 @@ sub push {
     my $self = shift;
 
     push(@$self, @_);
+
+    return;
 }
 
 sub format {
